"""AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
    _6852,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_AGMA_GLEASON_CONICAL_GEAR_MESH_COMPOUND_CRITICAL_SPEED_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses.Compound",
    "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
        _6690,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
        _6831,
        _6836,
        _6882,
        _6921,
        _6927,
        _6930,
        _6948,
        _6878,
        _6884,
        _6854,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7704,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar(
        "Self", bound="AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis._Cast_AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis:
    """Special nested class for casting AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis to subclasses."""

    __parent__: "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis"

    @property
    def conical_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6852.ConicalGearMeshCompoundCriticalSpeedAnalysis":
        return self.__parent__._cast(_6852.ConicalGearMeshCompoundCriticalSpeedAnalysis)

    @property
    def gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6878.GearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6878,
        )

        return self.__parent__._cast(_6878.GearMeshCompoundCriticalSpeedAnalysis)

    @property
    def inter_mountable_component_connection_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6884.InterMountableComponentConnectionCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6884,
        )

        return self.__parent__._cast(
            _6884.InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
        )

    @property
    def connection_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6854.ConnectionCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6854,
        )

        return self.__parent__._cast(_6854.ConnectionCompoundCriticalSpeedAnalysis)

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7704.ConnectionCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7704,
        )

        return self.__parent__._cast(_7704.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def bevel_differential_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6831.BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6831,
        )

        return self.__parent__._cast(
            _6831.BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
        )

    @property
    def bevel_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6836.BevelGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6836,
        )

        return self.__parent__._cast(_6836.BevelGearMeshCompoundCriticalSpeedAnalysis)

    @property
    def hypoid_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6882.HypoidGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6882,
        )

        return self.__parent__._cast(_6882.HypoidGearMeshCompoundCriticalSpeedAnalysis)

    @property
    def spiral_bevel_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6921.SpiralBevelGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6921,
        )

        return self.__parent__._cast(
            _6921.SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
        )

    @property
    def straight_bevel_diff_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6927.StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6927,
        )

        return self.__parent__._cast(
            _6927.StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
        )

    @property
    def straight_bevel_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6930.StraightBevelGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6930,
        )

        return self.__parent__._cast(
            _6930.StraightBevelGearMeshCompoundCriticalSpeedAnalysis
        )

    @property
    def zerol_bevel_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "_6948.ZerolBevelGearMeshCompoundCriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound import (
            _6948,
        )

        return self.__parent__._cast(
            _6948.ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
        )

    @property
    def agma_gleason_conical_gear_mesh_compound_critical_speed_analysis(
        self: "CastSelf",
    ) -> "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis(
    _6852.ConicalGearMeshCompoundCriticalSpeedAnalysis
):
    """AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar[
        "Type"
    ] = _AGMA_GLEASON_CONICAL_GEAR_MESH_COMPOUND_CRITICAL_SPEED_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_6690.AGMAGleasonConicalGearMeshCriticalSpeedAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.critical_speed_analyses.AGMAGleasonConicalGearMeshCriticalSpeedAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_6690.AGMAGleasonConicalGearMeshCriticalSpeedAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.critical_speed_analyses.AGMAGleasonConicalGearMeshCriticalSpeedAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis":
        """Cast to another type.

        Returns:
            _Cast_AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
        """
        return _Cast_AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis(self)



"""InnerShaftSocketBase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.system_model.connections_and_sockets import _2347
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_INNER_SHAFT_SOCKET_BASE = python_net_import(
    "SMT.MastaAPI.SystemModel.ConnectionsAndSockets", "InnerShaftSocketBase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.connections_and_sockets import (
        _2332,
        _2329,
        _2349,
    )
    from mastapy._private.system_model.connections_and_sockets.cycloidal import (
        _2386,
        _2389,
    )

    Self = TypeVar("Self", bound="InnerShaftSocketBase")
    CastSelf = TypeVar(
        "CastSelf", bound="InnerShaftSocketBase._Cast_InnerShaftSocketBase"
    )


__docformat__ = "restructuredtext en"
__all__ = ("InnerShaftSocketBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_InnerShaftSocketBase:
    """Special nested class for casting InnerShaftSocketBase to subclasses."""

    __parent__: "InnerShaftSocketBase"

    @property
    def shaft_socket(self: "CastSelf") -> "_2347.ShaftSocket":
        return self.__parent__._cast(_2347.ShaftSocket)

    @property
    def cylindrical_socket(self: "CastSelf") -> "_2329.CylindricalSocket":
        from mastapy._private.system_model.connections_and_sockets import _2329

        return self.__parent__._cast(_2329.CylindricalSocket)

    @property
    def socket(self: "CastSelf") -> "_2349.Socket":
        from mastapy._private.system_model.connections_and_sockets import _2349

        return self.__parent__._cast(_2349.Socket)

    @property
    def inner_shaft_socket(self: "CastSelf") -> "_2332.InnerShaftSocket":
        from mastapy._private.system_model.connections_and_sockets import _2332

        return self.__parent__._cast(_2332.InnerShaftSocket)

    @property
    def cycloidal_disc_axial_left_socket(
        self: "CastSelf",
    ) -> "_2386.CycloidalDiscAxialLeftSocket":
        from mastapy._private.system_model.connections_and_sockets.cycloidal import (
            _2386,
        )

        return self.__parent__._cast(_2386.CycloidalDiscAxialLeftSocket)

    @property
    def cycloidal_disc_inner_socket(
        self: "CastSelf",
    ) -> "_2389.CycloidalDiscInnerSocket":
        from mastapy._private.system_model.connections_and_sockets.cycloidal import (
            _2389,
        )

        return self.__parent__._cast(_2389.CycloidalDiscInnerSocket)

    @property
    def inner_shaft_socket_base(self: "CastSelf") -> "InnerShaftSocketBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class InnerShaftSocketBase(_2347.ShaftSocket):
    """InnerShaftSocketBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _INNER_SHAFT_SOCKET_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_InnerShaftSocketBase":
        """Cast to another type.

        Returns:
            _Cast_InnerShaftSocketBase
        """
        return _Cast_InnerShaftSocketBase(self)



"""FaceGearWheelDesign"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.gear_designs.face import _1013
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_FACE_GEAR_WHEEL_DESIGN = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Face", "FaceGearWheelDesign"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.gears.gear_designs.face import _1014
    from mastapy._private.gears.gear_designs import _971, _972

    Self = TypeVar("Self", bound="FaceGearWheelDesign")
    CastSelf = TypeVar(
        "CastSelf", bound="FaceGearWheelDesign._Cast_FaceGearWheelDesign"
    )


__docformat__ = "restructuredtext en"
__all__ = ("FaceGearWheelDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FaceGearWheelDesign:
    """Special nested class for casting FaceGearWheelDesign to subclasses."""

    __parent__: "FaceGearWheelDesign"

    @property
    def face_gear_design(self: "CastSelf") -> "_1013.FaceGearDesign":
        return self.__parent__._cast(_1013.FaceGearDesign)

    @property
    def gear_design(self: "CastSelf") -> "_971.GearDesign":
        from mastapy._private.gears.gear_designs import _971

        return self.__parent__._cast(_971.GearDesign)

    @property
    def gear_design_component(self: "CastSelf") -> "_972.GearDesignComponent":
        from mastapy._private.gears.gear_designs import _972

        return self.__parent__._cast(_972.GearDesignComponent)

    @property
    def face_gear_wheel_design(self: "CastSelf") -> "FaceGearWheelDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FaceGearWheelDesign(_1013.FaceGearDesign):
    """FaceGearWheelDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FACE_GEAR_WHEEL_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def addendum(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.Addendum

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @addendum.setter
    @enforce_parameter_types
    def addendum(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.Addendum = value

    @property
    def addendum_from_pitch_line_at_inner_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AddendumFromPitchLineAtInnerEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def addendum_from_pitch_line_at_mid_face(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AddendumFromPitchLineAtMidFace

        if temp is None:
            return 0.0

        return temp

    @property
    def addendum_from_pitch_line_at_outer_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AddendumFromPitchLineAtOuterEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def dedendum(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.Dedendum

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @dedendum.setter
    @enforce_parameter_types
    def dedendum(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.Dedendum = value

    @property
    def dedendum_from_pitch_line_at_inner_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DedendumFromPitchLineAtInnerEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def dedendum_from_pitch_line_at_mid_face(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DedendumFromPitchLineAtMidFace

        if temp is None:
            return 0.0

        return temp

    @property
    def dedendum_from_pitch_line_at_outer_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DedendumFromPitchLineAtOuterEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def face_width_offset(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceWidthOffset

        if temp is None:
            return 0.0

        return temp

    @face_width_offset.setter
    @enforce_parameter_types
    def face_width_offset(self: "Self", value: "float") -> None:
        self.wrapped.FaceWidthOffset = float(value) if value is not None else 0.0

    @property
    def face_width_and_diameters_specification_method(
        self: "Self",
    ) -> "_1014.FaceGearDiameterFaceWidthSpecificationMethod":
        """mastapy._private.gears.gear_designs.face.FaceGearDiameterFaceWidthSpecificationMethod"""
        temp = self.wrapped.FaceWidthAndDiametersSpecificationMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.GearDesigns.Face.FaceGearDiameterFaceWidthSpecificationMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.gear_designs.face._1014",
            "FaceGearDiameterFaceWidthSpecificationMethod",
        )(value)

    @face_width_and_diameters_specification_method.setter
    @enforce_parameter_types
    def face_width_and_diameters_specification_method(
        self: "Self", value: "_1014.FaceGearDiameterFaceWidthSpecificationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Gears.GearDesigns.Face.FaceGearDiameterFaceWidthSpecificationMethod",
        )
        self.wrapped.FaceWidthAndDiametersSpecificationMethod = value

    @property
    def fillet_radius_at_reference_section(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.FilletRadiusAtReferenceSection

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @fillet_radius_at_reference_section.setter
    @enforce_parameter_types
    def fillet_radius_at_reference_section(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.FilletRadiusAtReferenceSection = value

    @property
    def inner_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.InnerDiameter

        if temp is None:
            return 0.0

        return temp

    @inner_diameter.setter
    @enforce_parameter_types
    def inner_diameter(self: "Self", value: "float") -> None:
        self.wrapped.InnerDiameter = float(value) if value is not None else 0.0

    @property
    def mean_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_pitch_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanPitchDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_pitch_radius(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanPitchRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_pressure_angle_at_inner_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalPressureAngleAtInnerEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_pressure_angle_at_mid_face(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalPressureAngleAtMidFace

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_pressure_angle_at_outer_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalPressureAngleAtOuterEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_thickness_at_reference_section(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalThicknessAtReferenceSection

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.OuterDiameter

        if temp is None:
            return 0.0

        return temp

    @outer_diameter.setter
    @enforce_parameter_types
    def outer_diameter(self: "Self", value: "float") -> None:
        self.wrapped.OuterDiameter = float(value) if value is not None else 0.0

    @property
    def profile_shift_coefficient(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ProfileShiftCoefficient

        if temp is None:
            return 0.0

        return temp

    @property
    def radius_at_inner_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RadiusAtInnerEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def radius_at_mid_face(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RadiusAtMidFace

        if temp is None:
            return 0.0

        return temp

    @property
    def radius_at_outer_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RadiusAtOuterEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def reference_pitch_radius(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReferencePitchRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def rim_thickness(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.RimThickness

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @rim_thickness.setter
    @enforce_parameter_types
    def rim_thickness(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.RimThickness = value

    @property
    def whole_depth(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WholeDepth

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_FaceGearWheelDesign":
        """Cast to another type.

        Returns:
            _Cast_FaceGearWheelDesign
        """
        return _Cast_FaceGearWheelDesign(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5808 import (
        AbstractAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5809 import (
        AbstractPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5810 import (
        AbstractShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5811 import (
        AbstractShaftOrHousingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5812 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5813 import (
        AGMAGleasonConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5814 import (
        AGMAGleasonConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5815 import (
        AGMAGleasonConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5816 import (
        AssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5817 import (
        BearingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5818 import (
        BeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5819 import (
        BeltDriveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5820 import (
        BevelDifferentialGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5821 import (
        BevelDifferentialGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5822 import (
        BevelDifferentialGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5823 import (
        BevelDifferentialPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5824 import (
        BevelDifferentialSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5825 import (
        BevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5826 import (
        BevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5827 import (
        BevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5828 import (
        BoltedJointHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5829 import (
        BoltHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5830 import (
        ClutchConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5831 import (
        ClutchHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5832 import (
        ClutchHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5833 import (
        CoaxialConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5834 import (
        ComplianceAndForceData,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5835 import (
        ComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5836 import (
        ConceptCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5837 import (
        ConceptCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5838 import (
        ConceptCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5839 import (
        ConceptGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5840 import (
        ConceptGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5841 import (
        ConceptGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5842 import (
        ConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5843 import (
        ConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5844 import (
        ConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5845 import (
        ConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5846 import (
        ConnectorHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5847 import (
        CouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5848 import (
        CouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5849 import (
        CouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5850 import (
        CVTBeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5851 import (
        CVTHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5852 import (
        CVTPulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5853 import (
        CycloidalAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5854 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5855 import (
        CycloidalDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5856 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5857 import (
        CylindricalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5858 import (
        CylindricalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5859 import (
        CylindricalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5860 import (
        CylindricalPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5861 import (
        DatumHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5862 import (
        DynamicModelForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5863 import (
        ElectricMachinePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5864 import (
        ElectricMachineRotorXForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5865 import (
        ElectricMachineRotorXMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5866 import (
        ElectricMachineRotorYForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5867 import (
        ElectricMachineRotorYMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5868 import (
        ElectricMachineRotorZForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5869 import (
        ElectricMachineStatorToothAxialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5870 import (
        ElectricMachineStatorToothLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5871 import (
        ElectricMachineStatorToothMomentsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5872 import (
        ElectricMachineStatorToothRadialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5873 import (
        ElectricMachineStatorToothTangentialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5874 import (
        ElectricMachineTorqueRipplePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5875 import (
        ExportOutputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5876 import (
        ExternalCADModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5877 import (
        FaceGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5878 import (
        FaceGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5879 import (
        FaceGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5880 import (
        FEPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5881 import (
        FlexiblePinAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5882 import (
        FrequencyOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5883 import (
        GearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5884 import (
        GearMeshExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5885 import (
        GearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5886 import (
        GearMeshMisalignmentExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5887 import (
        GearMeshTEExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5888 import (
        GearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5889 import (
        GeneralPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5890 import (
        GuideDxfModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5891 import (
        HarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5892 import (
        HarmonicAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5893 import (
        HarmonicAnalysisExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5894 import (
        HarmonicAnalysisFEExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5895 import (
        HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5896 import (
        HarmonicAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5897 import (
        HarmonicAnalysisRootAssemblyExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5898 import (
        HarmonicAnalysisShaftExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5899 import (
        HarmonicAnalysisTorqueInputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5900 import (
        HarmonicAnalysisWithVaryingStiffnessStaticLoadCase,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5901 import (
        HypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5902 import (
        HypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5903 import (
        HypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5904 import (
        InterMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5905 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5906 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5907 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5908 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5909 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5910 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5911 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5912 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5913 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5914 import (
        MassDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5915 import (
        MeasurementComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5916 import (
        MicrophoneArrayHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5917 import (
        MicrophoneHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5918 import (
        MountableComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5919 import (
        OilSealHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5920 import (
        PartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5921 import (
        PartToPartShearCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5922 import (
        PartToPartShearCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5923 import (
        PartToPartShearCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5924 import (
        PeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5925 import (
        PlanetaryConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5926 import (
        PlanetaryGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5927 import (
        PlanetCarrierHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5928 import (
        PointLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5929 import (
        PowerLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5930 import (
        PulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5931 import (
        ResponseCacheLevel,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5932 import (
        RingPinsHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5933 import (
        RingPinsToDiscConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5934 import (
        RollingRingAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5935 import (
        RollingRingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5936 import (
        RollingRingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5937 import (
        RootAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5938 import (
        ShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5939 import (
        ShaftHubConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5940 import (
        ShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5941 import (
        SingleNodePeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5942 import (
        SpecialisedAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5943 import (
        SpeedOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5944 import (
        SpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5945 import (
        SpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5946 import (
        SpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5947 import (
        SpringDamperConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5948 import (
        SpringDamperHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5949 import (
        SpringDamperHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5950 import (
        StiffnessOptionsForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5951 import (
        StraightBevelDiffGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5952 import (
        StraightBevelDiffGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5953 import (
        StraightBevelDiffGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5954 import (
        StraightBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5955 import (
        StraightBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5956 import (
        StraightBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5957 import (
        StraightBevelPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5958 import (
        StraightBevelSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5959 import (
        SynchroniserHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5960 import (
        SynchroniserHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5961 import (
        SynchroniserPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5962 import (
        SynchroniserSleeveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5963 import (
        TorqueConverterConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5964 import (
        TorqueConverterHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5965 import (
        TorqueConverterPumpHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5966 import (
        TorqueConverterTurbineHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5967 import (
        UnbalancedMassExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5968 import (
        UnbalancedMassHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5969 import (
        VirtualComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5970 import (
        WormGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5971 import (
        WormGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5972 import (
        WormGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5973 import (
        ZerolBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5974 import (
        ZerolBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5975 import (
        ZerolBevelGearSetHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses._5808": [
            "AbstractAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5809": [
            "AbstractPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5810": [
            "AbstractShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5811": [
            "AbstractShaftOrHousingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5812": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5813": [
            "AGMAGleasonConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5814": [
            "AGMAGleasonConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5815": [
            "AGMAGleasonConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5816": [
            "AssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5817": [
            "BearingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5818": [
            "BeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5819": [
            "BeltDriveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5820": [
            "BevelDifferentialGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5821": [
            "BevelDifferentialGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5822": [
            "BevelDifferentialGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5823": [
            "BevelDifferentialPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5824": [
            "BevelDifferentialSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5825": [
            "BevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5826": [
            "BevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5827": [
            "BevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5828": [
            "BoltedJointHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5829": [
            "BoltHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5830": [
            "ClutchConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5831": [
            "ClutchHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5832": [
            "ClutchHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5833": [
            "CoaxialConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5834": [
            "ComplianceAndForceData"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5835": [
            "ComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5836": [
            "ConceptCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5837": [
            "ConceptCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5838": [
            "ConceptCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5839": [
            "ConceptGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5840": [
            "ConceptGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5841": [
            "ConceptGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5842": [
            "ConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5843": [
            "ConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5844": [
            "ConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5845": [
            "ConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5846": [
            "ConnectorHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5847": [
            "CouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5848": [
            "CouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5849": [
            "CouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5850": [
            "CVTBeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5851": [
            "CVTHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5852": [
            "CVTPulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5853": [
            "CycloidalAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5854": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5855": [
            "CycloidalDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5856": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5857": [
            "CylindricalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5858": [
            "CylindricalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5859": [
            "CylindricalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5860": [
            "CylindricalPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5861": [
            "DatumHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5862": [
            "DynamicModelForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5863": [
            "ElectricMachinePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5864": [
            "ElectricMachineRotorXForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5865": [
            "ElectricMachineRotorXMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5866": [
            "ElectricMachineRotorYForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5867": [
            "ElectricMachineRotorYMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5868": [
            "ElectricMachineRotorZForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5869": [
            "ElectricMachineStatorToothAxialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5870": [
            "ElectricMachineStatorToothLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5871": [
            "ElectricMachineStatorToothMomentsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5872": [
            "ElectricMachineStatorToothRadialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5873": [
            "ElectricMachineStatorToothTangentialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5874": [
            "ElectricMachineTorqueRipplePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5875": [
            "ExportOutputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5876": [
            "ExternalCADModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5877": [
            "FaceGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5878": [
            "FaceGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5879": [
            "FaceGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5880": [
            "FEPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5881": [
            "FlexiblePinAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5882": [
            "FrequencyOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5883": [
            "GearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5884": [
            "GearMeshExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5885": [
            "GearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5886": [
            "GearMeshMisalignmentExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5887": [
            "GearMeshTEExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5888": [
            "GearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5889": [
            "GeneralPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5890": [
            "GuideDxfModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5891": [
            "HarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5892": [
            "HarmonicAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5893": [
            "HarmonicAnalysisExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5894": [
            "HarmonicAnalysisFEExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5895": [
            "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5896": [
            "HarmonicAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5897": [
            "HarmonicAnalysisRootAssemblyExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5898": [
            "HarmonicAnalysisShaftExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5899": [
            "HarmonicAnalysisTorqueInputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5900": [
            "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5901": [
            "HypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5902": [
            "HypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5903": [
            "HypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5904": [
            "InterMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5905": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5906": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5907": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5908": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5909": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5910": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5911": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5912": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5913": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5914": [
            "MassDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5915": [
            "MeasurementComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5916": [
            "MicrophoneArrayHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5917": [
            "MicrophoneHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5918": [
            "MountableComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5919": [
            "OilSealHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5920": [
            "PartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5921": [
            "PartToPartShearCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5922": [
            "PartToPartShearCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5923": [
            "PartToPartShearCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5924": [
            "PeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5925": [
            "PlanetaryConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5926": [
            "PlanetaryGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5927": [
            "PlanetCarrierHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5928": [
            "PointLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5929": [
            "PowerLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5930": [
            "PulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5931": [
            "ResponseCacheLevel"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5932": [
            "RingPinsHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5933": [
            "RingPinsToDiscConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5934": [
            "RollingRingAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5935": [
            "RollingRingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5936": [
            "RollingRingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5937": [
            "RootAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5938": [
            "ShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5939": [
            "ShaftHubConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5940": [
            "ShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5941": [
            "SingleNodePeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5942": [
            "SpecialisedAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5943": [
            "SpeedOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5944": [
            "SpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5945": [
            "SpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5946": [
            "SpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5947": [
            "SpringDamperConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5948": [
            "SpringDamperHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5949": [
            "SpringDamperHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5950": [
            "StiffnessOptionsForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5951": [
            "StraightBevelDiffGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5952": [
            "StraightBevelDiffGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5953": [
            "StraightBevelDiffGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5954": [
            "StraightBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5955": [
            "StraightBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5956": [
            "StraightBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5957": [
            "StraightBevelPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5958": [
            "StraightBevelSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5959": [
            "SynchroniserHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5960": [
            "SynchroniserHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5961": [
            "SynchroniserPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5962": [
            "SynchroniserSleeveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5963": [
            "TorqueConverterConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5964": [
            "TorqueConverterHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5965": [
            "TorqueConverterPumpHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5966": [
            "TorqueConverterTurbineHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5967": [
            "UnbalancedMassExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5968": [
            "UnbalancedMassHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5969": [
            "VirtualComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5970": [
            "WormGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5971": [
            "WormGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5972": [
            "WormGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5973": [
            "ZerolBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5974": [
            "ZerolBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5975": [
            "ZerolBevelGearSetHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysis",
    "AbstractPeriodicExcitationDetail",
    "AbstractShaftHarmonicAnalysis",
    "AbstractShaftOrHousingHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysis",
    "AGMAGleasonConicalGearHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshHarmonicAnalysis",
    "AGMAGleasonConicalGearSetHarmonicAnalysis",
    "AssemblyHarmonicAnalysis",
    "BearingHarmonicAnalysis",
    "BeltConnectionHarmonicAnalysis",
    "BeltDriveHarmonicAnalysis",
    "BevelDifferentialGearHarmonicAnalysis",
    "BevelDifferentialGearMeshHarmonicAnalysis",
    "BevelDifferentialGearSetHarmonicAnalysis",
    "BevelDifferentialPlanetGearHarmonicAnalysis",
    "BevelDifferentialSunGearHarmonicAnalysis",
    "BevelGearHarmonicAnalysis",
    "BevelGearMeshHarmonicAnalysis",
    "BevelGearSetHarmonicAnalysis",
    "BoltedJointHarmonicAnalysis",
    "BoltHarmonicAnalysis",
    "ClutchConnectionHarmonicAnalysis",
    "ClutchHalfHarmonicAnalysis",
    "ClutchHarmonicAnalysis",
    "CoaxialConnectionHarmonicAnalysis",
    "ComplianceAndForceData",
    "ComponentHarmonicAnalysis",
    "ConceptCouplingConnectionHarmonicAnalysis",
    "ConceptCouplingHalfHarmonicAnalysis",
    "ConceptCouplingHarmonicAnalysis",
    "ConceptGearHarmonicAnalysis",
    "ConceptGearMeshHarmonicAnalysis",
    "ConceptGearSetHarmonicAnalysis",
    "ConicalGearHarmonicAnalysis",
    "ConicalGearMeshHarmonicAnalysis",
    "ConicalGearSetHarmonicAnalysis",
    "ConnectionHarmonicAnalysis",
    "ConnectorHarmonicAnalysis",
    "CouplingConnectionHarmonicAnalysis",
    "CouplingHalfHarmonicAnalysis",
    "CouplingHarmonicAnalysis",
    "CVTBeltConnectionHarmonicAnalysis",
    "CVTHarmonicAnalysis",
    "CVTPulleyHarmonicAnalysis",
    "CycloidalAssemblyHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysis",
    "CycloidalDiscHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis",
    "CylindricalGearHarmonicAnalysis",
    "CylindricalGearMeshHarmonicAnalysis",
    "CylindricalGearSetHarmonicAnalysis",
    "CylindricalPlanetGearHarmonicAnalysis",
    "DatumHarmonicAnalysis",
    "DynamicModelForHarmonicAnalysis",
    "ElectricMachinePeriodicExcitationDetail",
    "ElectricMachineRotorXForcePeriodicExcitationDetail",
    "ElectricMachineRotorXMomentPeriodicExcitationDetail",
    "ElectricMachineRotorYForcePeriodicExcitationDetail",
    "ElectricMachineRotorYMomentPeriodicExcitationDetail",
    "ElectricMachineRotorZForcePeriodicExcitationDetail",
    "ElectricMachineStatorToothAxialLoadsExcitationDetail",
    "ElectricMachineStatorToothLoadsExcitationDetail",
    "ElectricMachineStatorToothMomentsExcitationDetail",
    "ElectricMachineStatorToothRadialLoadsExcitationDetail",
    "ElectricMachineStatorToothTangentialLoadsExcitationDetail",
    "ElectricMachineTorqueRipplePeriodicExcitationDetail",
    "ExportOutputType",
    "ExternalCADModelHarmonicAnalysis",
    "FaceGearHarmonicAnalysis",
    "FaceGearMeshHarmonicAnalysis",
    "FaceGearSetHarmonicAnalysis",
    "FEPartHarmonicAnalysis",
    "FlexiblePinAssemblyHarmonicAnalysis",
    "FrequencyOptionsForHarmonicAnalysisResults",
    "GearHarmonicAnalysis",
    "GearMeshExcitationDetail",
    "GearMeshHarmonicAnalysis",
    "GearMeshMisalignmentExcitationDetail",
    "GearMeshTEExcitationDetail",
    "GearSetHarmonicAnalysis",
    "GeneralPeriodicExcitationDetail",
    "GuideDxfModelHarmonicAnalysis",
    "HarmonicAnalysis",
    "HarmonicAnalysisDrawStyle",
    "HarmonicAnalysisExportOptions",
    "HarmonicAnalysisFEExportOptions",
    "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation",
    "HarmonicAnalysisOptions",
    "HarmonicAnalysisRootAssemblyExportOptions",
    "HarmonicAnalysisShaftExportOptions",
    "HarmonicAnalysisTorqueInputType",
    "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase",
    "HypoidGearHarmonicAnalysis",
    "HypoidGearMeshHarmonicAnalysis",
    "HypoidGearSetHarmonicAnalysis",
    "InterMountableComponentConnectionHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis",
    "MassDiscHarmonicAnalysis",
    "MeasurementComponentHarmonicAnalysis",
    "MicrophoneArrayHarmonicAnalysis",
    "MicrophoneHarmonicAnalysis",
    "MountableComponentHarmonicAnalysis",
    "OilSealHarmonicAnalysis",
    "PartHarmonicAnalysis",
    "PartToPartShearCouplingConnectionHarmonicAnalysis",
    "PartToPartShearCouplingHalfHarmonicAnalysis",
    "PartToPartShearCouplingHarmonicAnalysis",
    "PeriodicExcitationWithReferenceShaft",
    "PlanetaryConnectionHarmonicAnalysis",
    "PlanetaryGearSetHarmonicAnalysis",
    "PlanetCarrierHarmonicAnalysis",
    "PointLoadHarmonicAnalysis",
    "PowerLoadHarmonicAnalysis",
    "PulleyHarmonicAnalysis",
    "ResponseCacheLevel",
    "RingPinsHarmonicAnalysis",
    "RingPinsToDiscConnectionHarmonicAnalysis",
    "RollingRingAssemblyHarmonicAnalysis",
    "RollingRingConnectionHarmonicAnalysis",
    "RollingRingHarmonicAnalysis",
    "RootAssemblyHarmonicAnalysis",
    "ShaftHarmonicAnalysis",
    "ShaftHubConnectionHarmonicAnalysis",
    "ShaftToMountableComponentConnectionHarmonicAnalysis",
    "SingleNodePeriodicExcitationWithReferenceShaft",
    "SpecialisedAssemblyHarmonicAnalysis",
    "SpeedOptionsForHarmonicAnalysisResults",
    "SpiralBevelGearHarmonicAnalysis",
    "SpiralBevelGearMeshHarmonicAnalysis",
    "SpiralBevelGearSetHarmonicAnalysis",
    "SpringDamperConnectionHarmonicAnalysis",
    "SpringDamperHalfHarmonicAnalysis",
    "SpringDamperHarmonicAnalysis",
    "StiffnessOptionsForHarmonicAnalysis",
    "StraightBevelDiffGearHarmonicAnalysis",
    "StraightBevelDiffGearMeshHarmonicAnalysis",
    "StraightBevelDiffGearSetHarmonicAnalysis",
    "StraightBevelGearHarmonicAnalysis",
    "StraightBevelGearMeshHarmonicAnalysis",
    "StraightBevelGearSetHarmonicAnalysis",
    "StraightBevelPlanetGearHarmonicAnalysis",
    "StraightBevelSunGearHarmonicAnalysis",
    "SynchroniserHalfHarmonicAnalysis",
    "SynchroniserHarmonicAnalysis",
    "SynchroniserPartHarmonicAnalysis",
    "SynchroniserSleeveHarmonicAnalysis",
    "TorqueConverterConnectionHarmonicAnalysis",
    "TorqueConverterHarmonicAnalysis",
    "TorqueConverterPumpHarmonicAnalysis",
    "TorqueConverterTurbineHarmonicAnalysis",
    "UnbalancedMassExcitationDetail",
    "UnbalancedMassHarmonicAnalysis",
    "VirtualComponentHarmonicAnalysis",
    "WormGearHarmonicAnalysis",
    "WormGearMeshHarmonicAnalysis",
    "WormGearSetHarmonicAnalysis",
    "ZerolBevelGearHarmonicAnalysis",
    "ZerolBevelGearMeshHarmonicAnalysis",
    "ZerolBevelGearSetHarmonicAnalysis",
)



"""CylindricalGearMaterial"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item, overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private.gears.materials import _608
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_MATERIAL = python_net_import(
    "SMT.MastaAPI.Gears.Materials", "CylindricalGearMaterial"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.gears.materials import _622, _594, _616, _625
    from mastapy._private.materials import _280
    from mastapy._private.utility.databases import _1879

    Self = TypeVar("Self", bound="CylindricalGearMaterial")
    CastSelf = TypeVar(
        "CastSelf", bound="CylindricalGearMaterial._Cast_CylindricalGearMaterial"
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearMaterial",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearMaterial:
    """Special nested class for casting CylindricalGearMaterial to subclasses."""

    __parent__: "CylindricalGearMaterial"

    @property
    def gear_material(self: "CastSelf") -> "_608.GearMaterial":
        return self.__parent__._cast(_608.GearMaterial)

    @property
    def material(self: "CastSelf") -> "_280.Material":
        from mastapy._private.materials import _280

        return self.__parent__._cast(_280.Material)

    @property
    def named_database_item(self: "CastSelf") -> "_1879.NamedDatabaseItem":
        from mastapy._private.utility.databases import _1879

        return self.__parent__._cast(_1879.NamedDatabaseItem)

    @property
    def agma_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "_594.AGMACylindricalGearMaterial":
        from mastapy._private.gears.materials import _594

        return self.__parent__._cast(_594.AGMACylindricalGearMaterial)

    @property
    def iso_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "_616.ISOCylindricalGearMaterial":
        from mastapy._private.gears.materials import _616

        return self.__parent__._cast(_616.ISOCylindricalGearMaterial)

    @property
    def plastic_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "_625.PlasticCylindricalGearMaterial":
        from mastapy._private.gears.materials import _625

        return self.__parent__._cast(_625.PlasticCylindricalGearMaterial)

    @property
    def cylindrical_gear_material(self: "CastSelf") -> "CylindricalGearMaterial":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearMaterial(_608.GearMaterial):
    """CylindricalGearMaterial

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_MATERIAL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def allowable_stress_number_bending(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AllowableStressNumberBending

        if temp is None:
            return 0.0

        return temp

    @allowable_stress_number_bending.setter
    @enforce_parameter_types
    def allowable_stress_number_bending(self: "Self", value: "float") -> None:
        self.wrapped.AllowableStressNumberBending = (
            float(value) if value is not None else 0.0
        )

    @property
    def allowable_stress_number_contact(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AllowableStressNumberContact

        if temp is None:
            return 0.0

        return temp

    @allowable_stress_number_contact.setter
    @enforce_parameter_types
    def allowable_stress_number_contact(self: "Self", value: "float") -> None:
        self.wrapped.AllowableStressNumberContact = (
            float(value) if value is not None else 0.0
        )

    @property
    def heat_treatment_distortion_control(self: "Self") -> "_622.ManufactureRating":
        """mastapy._private.gears.materials.ManufactureRating"""
        temp = self.wrapped.HeatTreatmentDistortionControl

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.materials._622", "ManufactureRating"
        )(value)

    @heat_treatment_distortion_control.setter
    @enforce_parameter_types
    def heat_treatment_distortion_control(
        self: "Self", value: "_622.ManufactureRating"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )
        self.wrapped.HeatTreatmentDistortionControl = value

    @property
    def heat_treatment_process_development(self: "Self") -> "_622.ManufactureRating":
        """mastapy._private.gears.materials.ManufactureRating"""
        temp = self.wrapped.HeatTreatmentProcessDevelopment

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.materials._622", "ManufactureRating"
        )(value)

    @heat_treatment_process_development.setter
    @enforce_parameter_types
    def heat_treatment_process_development(
        self: "Self", value: "_622.ManufactureRating"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )
        self.wrapped.HeatTreatmentProcessDevelopment = value

    @property
    def machine_process_development(self: "Self") -> "_622.ManufactureRating":
        """mastapy._private.gears.materials.ManufactureRating"""
        temp = self.wrapped.MachineProcessDevelopment

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.materials._622", "ManufactureRating"
        )(value)

    @machine_process_development.setter
    @enforce_parameter_types
    def machine_process_development(
        self: "Self", value: "_622.ManufactureRating"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )
        self.wrapped.MachineProcessDevelopment = value

    @property
    def manufacturability(self: "Self") -> "_622.ManufactureRating":
        """mastapy._private.gears.materials.ManufactureRating"""
        temp = self.wrapped.Manufacturability

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.materials._622", "ManufactureRating"
        )(value)

    @manufacturability.setter
    @enforce_parameter_types
    def manufacturability(self: "Self", value: "_622.ManufactureRating") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Gears.Materials.ManufactureRating"
        )
        self.wrapped.Manufacturability = value

    @property
    def material_type(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = self.wrapped.MaterialType

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @material_type.setter
    @enforce_parameter_types
    def material_type(self: "Self", value: "str") -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else ""
        )
        self.wrapped.MaterialType = value

    @property
    def nominal_stress_number_bending(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.NominalStressNumberBending

        if temp is None:
            return 0.0

        return temp

    @nominal_stress_number_bending.setter
    @enforce_parameter_types
    def nominal_stress_number_bending(self: "Self", value: "float") -> None:
        self.wrapped.NominalStressNumberBending = (
            float(value) if value is not None else 0.0
        )

    @property
    def retained_austenite(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RetainedAustenite

        if temp is None:
            return 0.0

        return temp

    @retained_austenite.setter
    @enforce_parameter_types
    def retained_austenite(self: "Self", value: "float") -> None:
        self.wrapped.RetainedAustenite = float(value) if value is not None else 0.0

    @property
    def sn_curve_bending_allowable_stress_point_selector(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = self.wrapped.SNCurveBendingAllowableStressPointSelector

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @sn_curve_bending_allowable_stress_point_selector.setter
    @enforce_parameter_types
    def sn_curve_bending_allowable_stress_point_selector(
        self: "Self", value: "str"
    ) -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else ""
        )
        self.wrapped.SNCurveBendingAllowableStressPointSelector = value

    @property
    def sn_curve_contact_allowable_stress_point_selector(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = self.wrapped.SNCurveContactAllowableStressPointSelector

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @sn_curve_contact_allowable_stress_point_selector.setter
    @enforce_parameter_types
    def sn_curve_contact_allowable_stress_point_selector(
        self: "Self", value: "str"
    ) -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else ""
        )
        self.wrapped.SNCurveContactAllowableStressPointSelector = value

    @property
    def shot_peened(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ShotPeened

        if temp is None:
            return False

        return temp

    @shot_peened.setter
    @enforce_parameter_types
    def shot_peened(self: "Self", value: "bool") -> None:
        self.wrapped.ShotPeened = bool(value) if value is not None else False

    @property
    def specify_allowable_stress_number_bending(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.SpecifyAllowableStressNumberBending

        if temp is None:
            return False

        return temp

    @specify_allowable_stress_number_bending.setter
    @enforce_parameter_types
    def specify_allowable_stress_number_bending(self: "Self", value: "bool") -> None:
        self.wrapped.SpecifyAllowableStressNumberBending = (
            bool(value) if value is not None else False
        )

    @property
    def specify_allowable_stress_number_contact(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.SpecifyAllowableStressNumberContact

        if temp is None:
            return False

        return temp

    @specify_allowable_stress_number_contact.setter
    @enforce_parameter_types
    def specify_allowable_stress_number_contact(self: "Self", value: "bool") -> None:
        self.wrapped.SpecifyAllowableStressNumberContact = (
            bool(value) if value is not None else False
        )

    @property
    def welding_structural_factor(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.WeldingStructuralFactor

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @welding_structural_factor.setter
    @enforce_parameter_types
    def welding_structural_factor(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.WeldingStructuralFactor = value

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearMaterial":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearMaterial
        """
        return _Cast_CylindricalGearMaterial(self)



"""SpecialisedAssemblyModalAnalysisAtAStiffness"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
    _4972,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_SPECIALISED_ASSEMBLY_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness",
    "SpecialisedAssemblyModalAnalysisAtAStiffness",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model import _2532
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _4978,
        _4982,
        _4985,
        _4990,
        _4991,
        _4995,
        _5000,
        _5003,
        _5006,
        _5011,
        _5013,
        _5015,
        _5021,
        _5028,
        _5030,
        _5033,
        _5037,
        _5041,
        _5044,
        _5047,
        _5050,
        _5058,
        _5060,
        _5067,
        _5077,
        _5080,
        _5083,
        _5086,
        _5090,
        _5094,
        _5101,
        _5104,
        _5055,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7713,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="SpecialisedAssemblyModalAnalysisAtAStiffness")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SpecialisedAssemblyModalAnalysisAtAStiffness._Cast_SpecialisedAssemblyModalAnalysisAtAStiffness",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpecialisedAssemblyModalAnalysisAtAStiffness",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpecialisedAssemblyModalAnalysisAtAStiffness:
    """Special nested class for casting SpecialisedAssemblyModalAnalysisAtAStiffness to subclasses."""

    __parent__: "SpecialisedAssemblyModalAnalysisAtAStiffness"

    @property
    def abstract_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4972.AbstractAssemblyModalAnalysisAtAStiffness":
        return self.__parent__._cast(_4972.AbstractAssemblyModalAnalysisAtAStiffness)

    @property
    def part_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5055.PartModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5055,
        )

        return self.__parent__._cast(_5055.PartModalAnalysisAtAStiffness)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7713,
        )

        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4978.AGMAGleasonConicalGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4978,
        )

        return self.__parent__._cast(
            _4978.AGMAGleasonConicalGearSetModalAnalysisAtAStiffness
        )

    @property
    def belt_drive_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4982.BeltDriveModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4982,
        )

        return self.__parent__._cast(_4982.BeltDriveModalAnalysisAtAStiffness)

    @property
    def bevel_differential_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4985.BevelDifferentialGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4985,
        )

        return self.__parent__._cast(
            _4985.BevelDifferentialGearSetModalAnalysisAtAStiffness
        )

    @property
    def bevel_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4990.BevelGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4990,
        )

        return self.__parent__._cast(_4990.BevelGearSetModalAnalysisAtAStiffness)

    @property
    def bolted_joint_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4991.BoltedJointModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4991,
        )

        return self.__parent__._cast(_4991.BoltedJointModalAnalysisAtAStiffness)

    @property
    def clutch_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4995.ClutchModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4995,
        )

        return self.__parent__._cast(_4995.ClutchModalAnalysisAtAStiffness)

    @property
    def concept_coupling_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5000.ConceptCouplingModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5000,
        )

        return self.__parent__._cast(_5000.ConceptCouplingModalAnalysisAtAStiffness)

    @property
    def concept_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5003.ConceptGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5003,
        )

        return self.__parent__._cast(_5003.ConceptGearSetModalAnalysisAtAStiffness)

    @property
    def conical_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5006.ConicalGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5006,
        )

        return self.__parent__._cast(_5006.ConicalGearSetModalAnalysisAtAStiffness)

    @property
    def coupling_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5011.CouplingModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5011,
        )

        return self.__parent__._cast(_5011.CouplingModalAnalysisAtAStiffness)

    @property
    def cvt_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5013.CVTModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5013,
        )

        return self.__parent__._cast(_5013.CVTModalAnalysisAtAStiffness)

    @property
    def cycloidal_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5015.CycloidalAssemblyModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5015,
        )

        return self.__parent__._cast(_5015.CycloidalAssemblyModalAnalysisAtAStiffness)

    @property
    def cylindrical_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5021.CylindricalGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5021,
        )

        return self.__parent__._cast(_5021.CylindricalGearSetModalAnalysisAtAStiffness)

    @property
    def face_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5028.FaceGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5028,
        )

        return self.__parent__._cast(_5028.FaceGearSetModalAnalysisAtAStiffness)

    @property
    def flexible_pin_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5030.FlexiblePinAssemblyModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5030,
        )

        return self.__parent__._cast(_5030.FlexiblePinAssemblyModalAnalysisAtAStiffness)

    @property
    def gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5033.GearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5033,
        )

        return self.__parent__._cast(_5033.GearSetModalAnalysisAtAStiffness)

    @property
    def hypoid_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5037.HypoidGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5037,
        )

        return self.__parent__._cast(_5037.HypoidGearSetModalAnalysisAtAStiffness)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5041.KlingelnbergCycloPalloidConicalGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5041,
        )

        return self.__parent__._cast(
            _5041.KlingelnbergCycloPalloidConicalGearSetModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5044.KlingelnbergCycloPalloidHypoidGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5044,
        )

        return self.__parent__._cast(
            _5044.KlingelnbergCycloPalloidHypoidGearSetModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5047.KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5047,
        )

        return self.__parent__._cast(
            _5047.KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysisAtAStiffness
        )

    @property
    def microphone_array_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5050.MicrophoneArrayModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5050,
        )

        return self.__parent__._cast(_5050.MicrophoneArrayModalAnalysisAtAStiffness)

    @property
    def part_to_part_shear_coupling_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5058.PartToPartShearCouplingModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5058,
        )

        return self.__parent__._cast(
            _5058.PartToPartShearCouplingModalAnalysisAtAStiffness
        )

    @property
    def planetary_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5060.PlanetaryGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5060,
        )

        return self.__parent__._cast(_5060.PlanetaryGearSetModalAnalysisAtAStiffness)

    @property
    def rolling_ring_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5067.RollingRingAssemblyModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5067,
        )

        return self.__parent__._cast(_5067.RollingRingAssemblyModalAnalysisAtAStiffness)

    @property
    def spiral_bevel_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5077.SpiralBevelGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5077,
        )

        return self.__parent__._cast(_5077.SpiralBevelGearSetModalAnalysisAtAStiffness)

    @property
    def spring_damper_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5080.SpringDamperModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5080,
        )

        return self.__parent__._cast(_5080.SpringDamperModalAnalysisAtAStiffness)

    @property
    def straight_bevel_diff_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5083.StraightBevelDiffGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5083,
        )

        return self.__parent__._cast(
            _5083.StraightBevelDiffGearSetModalAnalysisAtAStiffness
        )

    @property
    def straight_bevel_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5086.StraightBevelGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5086,
        )

        return self.__parent__._cast(
            _5086.StraightBevelGearSetModalAnalysisAtAStiffness
        )

    @property
    def synchroniser_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5090.SynchroniserModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5090,
        )

        return self.__parent__._cast(_5090.SynchroniserModalAnalysisAtAStiffness)

    @property
    def torque_converter_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5094.TorqueConverterModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5094,
        )

        return self.__parent__._cast(_5094.TorqueConverterModalAnalysisAtAStiffness)

    @property
    def worm_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5101.WormGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5101,
        )

        return self.__parent__._cast(_5101.WormGearSetModalAnalysisAtAStiffness)

    @property
    def zerol_bevel_gear_set_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5104.ZerolBevelGearSetModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5104,
        )

        return self.__parent__._cast(_5104.ZerolBevelGearSetModalAnalysisAtAStiffness)

    @property
    def specialised_assembly_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "SpecialisedAssemblyModalAnalysisAtAStiffness":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class SpecialisedAssemblyModalAnalysisAtAStiffness(
    _4972.AbstractAssemblyModalAnalysisAtAStiffness
):
    """SpecialisedAssemblyModalAnalysisAtAStiffness

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPECIALISED_ASSEMBLY_MODAL_ANALYSIS_AT_A_STIFFNESS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def assembly_design(self: "Self") -> "_2532.SpecialisedAssembly":
        """mastapy._private.system_model.part_model.SpecialisedAssembly

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_SpecialisedAssemblyModalAnalysisAtAStiffness":
        """Cast to another type.

        Returns:
            _Cast_SpecialisedAssemblyModalAnalysisAtAStiffness
        """
        return _Cast_SpecialisedAssemblyModalAnalysisAtAStiffness(self)



"""Frequencies"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.bearings.bearing_results.rolling.skf_module import _2149
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_FREQUENCIES = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling.SkfModule", "Frequencies"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_results.rolling.skf_module import (
        _2135,
        _2147,
    )

    Self = TypeVar("Self", bound="Frequencies")
    CastSelf = TypeVar("CastSelf", bound="Frequencies._Cast_Frequencies")


__docformat__ = "restructuredtext en"
__all__ = ("Frequencies",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Frequencies:
    """Special nested class for casting Frequencies to subclasses."""

    __parent__: "Frequencies"

    @property
    def skf_calculation_result(self: "CastSelf") -> "_2149.SKFCalculationResult":
        return self.__parent__._cast(_2149.SKFCalculationResult)

    @property
    def frequencies(self: "CastSelf") -> "Frequencies":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Frequencies(_2149.SKFCalculationResult):
    """Frequencies

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FREQUENCIES

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def frequency_of_over_rolling(self: "Self") -> "_2135.FrequencyOfOverRolling":
        """mastapy._private.bearings.bearing_results.rolling.skf_module.FrequencyOfOverRolling

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FrequencyOfOverRolling

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rotational_frequency(self: "Self") -> "_2147.RotationalFrequency":
        """mastapy._private.bearings.bearing_results.rolling.skf_module.RotationalFrequency

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RotationalFrequency

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_Frequencies":
        """Cast to another type.

        Returns:
            _Cast_Frequencies
        """
        return _Cast_Frequencies(self)
